@@ -31,9 +31,9 @@ import {
   medicationFrequencySchema,
 } from './definitions/medicationFrequencySchema';
 
-const generateFrequencyProperties = (frequencies) => {
+const generateFrequencyProperties = frequencies => {
   return Object.fromEntries(
-    frequencies.map((frequency) => [
+    frequencies.map(frequency => [
       frequency,
       {
         description: frequency,
@@ -306,6 +306,21 @@ export const globalSettings = {
           type: yup.boolean(),
           defaultValue: false,
         },
+        pharmacyOrder: {
+          description: 'Pharmacy order settings',
+          properties: {
+            enabled: {
+              description: 'Enable pharmacy orders',
+              type: yup.boolean(),
+              defaultValue: false,
+            },
+          },
+        },
+        useGlobalPdfFont: {
+          description: 'Use the global PDF font for all PDFs',
+          type: yup.boolean(),
+          defaultValue: false,
+        },
       },
     },
     customisations: {
@@ -1440,9 +1455,15 @@ export const globalSettings = {
         },
         defaultAdministrationTimes: {
           description: '-',
-          properties: generateFrequencyProperties(Object.values(ADMINISTRATION_FREQUENCIES).filter(
-            frequency => ![ADMINISTRATION_FREQUENCIES.IMMEDIATELY, ADMINISTRATION_FREQUENCIES.AS_DIRECTED].includes(frequency)
-          )),
+          properties: generateFrequencyProperties(
+            Object.values(ADMINISTRATION_FREQUENCIES).filter(
+              frequency =>
+                ![
+                  ADMINISTRATION_FREQUENCIES.IMMEDIATELY,
+                  ADMINISTRATION_FREQUENCIES.AS_DIRECTED,
+                ].includes(frequency),
+            ),
+          ),
         },
       },
     },
